==> flatland-model-diagram-editor-0.1.19.tar.gz: flatland-model-diagram-editor-0.1.19/flatland/Database/Population/Drawing/closed_shape_fill_instances.py <==
"""
closed_shape_fill_instances.py
"""

population = [
    # Starr/default symbols
    {'Asset': 'solid arrow', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Fill': 'black'},
    {'Asset': 'hollow arrow', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'gen arrow', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'class compartment', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'default', 'Drawing type': 'Starr class diagram',
     'Fill': 'white'},

    # Starr/diagnostic symbols
    {'Asset': 'solid arrow', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram', 'Fill': 'black'},
    {'Asset': 'hollow arrow', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'gen arrow', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'class compartment', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram',
     'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram',
     'Fill': 'white'},

    # Shlaer-Mellor/default symbols
    {'Asset': 'class compartment', 'Presentation': 'default', 'Drawing type': 'Shlaer-Mellor class diagram',
     'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'default', 'Drawing type': 'Shlaer-Mellor class diagram',
     'Fill': 'white'},
    # Shlaer-Mellor/diagnostic
    {'Asset': 'class compartment', 'Presentation': 'diagnostic', 'Drawing type': 'Shlaer-Mellor class diagram',
     'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'diagnostic', 'Drawing type': 'Shlaer-Mellor class diagram',
     'Fill': 'white'},

    # xUML/default
    {'Asset': 'class compartment', 'Presentation': 'default', 'Drawing type': 'xUML class diagram', 'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'default', 'Drawing type': 'xUML class diagram', 'Fill': 'white'},
    {'Asset': 'state compartment', 'Presentation': 'default', 'Drawing type': 'xUML state machine diagram',
     'Fill': 'white'},
    {'Asset': 'solid dot', 'Presentation': 'default', 'Drawing type': 'xUML state machine diagram', 'Fill': 'black'},
    {'Asset': 'hollow large circle', 'Presentation': 'default', 'Drawing type': 'xUML state machine diagram',
     'Fill': 'white'},

]

==> flatland-model-diagram-editor-0.2.1.tar.gz: flatland-model-diagram-editor-0.2.1/flatland/Database/Population/Drawing/closed_shape_fill_instances.py <==
"""
closed_shape_fill_instances.py
"""

population = [
    # Starr/default symbols
    {'Asset': 'solid arrow', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Fill': 'black'},
    {'Asset': 'hollow arrow', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'gen arrow', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'class compartment', 'Presentation': 'default', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'default', 'Drawing type': 'Starr class diagram',
     'Fill': 'white'},

    # Starr/diagnostic symbols
    {'Asset': 'solid arrow', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram', 'Fill': 'black'},
    {'Asset': 'hollow arrow', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'gen arrow', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram', 'Fill': 'white'},
    {'Asset': 'class compartment', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram',
     'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'diagnostic', 'Drawing type': 'Starr class diagram',
     'Fill': 'white'},

    # Shlaer-Mellor/default symbols
    {'Asset': 'class compartment', 'Presentation': 'default', 'Drawing type': 'Shlaer-Mellor class diagram',
     'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'default', 'Drawing type': 'Shlaer-Mellor class diagram',
     'Fill': 'white'},
    # Shlaer-Mellor/diagnostic
    {'Asset': 'class compartment', 'Presentation': 'diagnostic', 'Drawing type': 'Shlaer-Mellor class diagram',
     'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'diagnostic', 'Drawing type': 'Shlaer-Mellor class diagram',
     'Fill': 'white'},

    # xuml/default
    {'Asset': 'class compartment', 'Presentation': 'default', 'Drawing type': 'xuml class diagram', 'Fill': 'white'},
    {'Asset': 'imported class compartment', 'Presentation': 'default', 'Drawing type': 'xuml class diagram', 'Fill': 'white'},
    {'Asset': 'state compartment', 'Presentation': 'default', 'Drawing type': 'xuml state machine diagram',
     'Fill': 'white'},
    {'Asset': 'solid dot', 'Presentation': 'default', 'Drawing type': 'xuml state machine diagram', 'Fill': 'black'},
    {'Asset': 'hollow large circle', 'Presentation': 'default', 'Drawing type': 'xuml state machine diagram',
     'Fill': 'white'},

]
